
# ~/.profile: executed by ash, bash and pdksh for login shells.
# No bashishms allowed

# Folding used. Get folding.el for your emacs here:
# http://www.csd.uu.se/~andersl/emacs.shtml

#echo "~/.profile"

# {{{ Loading help 1

HOME_PROFILE=1
export HOME_PROFILE

# }}}
# {{{ $ENV etc.

# ftp://ftp.oreilly.com/pub/examples/power_tools/unix/split/sh_logout.sh
#echo "Setting logout behaviour"
#trap '. $HOME/.sh_logout.sh; exit' 0

case "$SHELL" in
    # ftp://ftp.oreilly.com/pub/examples/power_tools/unix/split/sh_logout.sh
    #echo "Setting logout behaviour"
    #trap '. $HOME/.sh_logout.sh; exit' 0
    *zsh*|*bash*)
    :
    ;;
    *)
    trap '. $HOME/.sh_logout.sh 2> /dev/null ' 0
esac

case "$SHELL" in
    # Zsh tries to emulate sh or ksh when it is invoked as sh or ksh respectively;
    # The usual zsh startup/shutdown scripts are not executed. Login shells
    # source /etc/profile followed by $HOME/.profile. If the ENV environment
    # variable is set on invocation, $ENV is sourced after the profile scripts.
    *zsh*)
    ENV="$HOME/.shinit.sh"
    export ENV
    BASH_ENV="$HOME/.bashrc"
    export BASH_ENV
    ;;

    *bash*)
    BASH_ENV="$HOME/.bashrc"
    export BASH_ENV
    ENV="$HOME/.bashrc"
    export ENV
    ;;

    *ksh*)
    BASH_ENV="$HOME/.bashrc"
    export BASH_ENV
    ENV="$HOME/.kshrc"
    export ENV
    ;;

    *)
    BASH_ENV="$HOME/.bashrc"
    export BASH_ENV
    ENV="$HOME/.shinit.sh"
    export ENV
esac

# }}}
# {{{ Loading help 2

if [ -n "$HOME_SHINIT" ]
then
    if [ "$HOME_SHINIT" -gt 0 ]
    then
        #echo PAH ~/.shinit.sh
        :
    fi
else
    #echo SUCK ~/.shinit.sh
    . "${HOME}/.shinit.sh"
    HOME_SHINIT="1"
    export HOME_SHINIT
fi

# }}}
# {{{ Misc

#mesg y

# Ensure 8 bit connection

#stty -parenb -istrip cs8
#stty pass8
#stty erase '^?'

# Paranoia

umask 022

# }}}
# {{{ Distribution-specific stuff

# linux_logo AND Welcome2L

# http://www.deater.net/weave/vmwprod/linux_logo/

# http://www.littleigloo.org/
# http://www.littleigloo.org/software_003.php3

# These cause some problems in XDM/GDM/KDM

#if test -f "/etc/debian_version"
#then
#  if test -f "$HOME/.profile.debian.sh"
#  then
#    if test -n "$PROFILE_DEBIAN"
#    then
#      if test "$PROFILE_DEBIAN" -gt 0
#      then
#      :
#      echo PAH ~/.profile.debian.sh
#      fi
#    else
#      echo SUCK ~/.profile.debian.sh
#      . "${HOME}/.profile.debian.sh"
#    fi
#  fi
#fi

#if test -f "/etc/redhat-release"
#then
#  if test -f "$HOME/.profile.redhat.sh"
#  then
#    if test -n "$PROFILE_REDHAT"
#    then
#      if test "$PROFILE_REDHAT" -gt 0
#      then
#      :
#      #echo PAH ~/.profile.redhat.sh
#      fi
#    else
#      #echo SUCK ~/.profile.redhat.sh
#      . "${HOME}/.profile.redhat.sh"
#    fi
#  fi
#fi

# Add some directory to PATH if it really exists
# and if it really is directory and if it is not
# yet in PATH
pathmunge ()
{
    if ! echo $PATH | /bin/egrep "(^|:)$1($|:)" > /dev/null 2>&1
    then
        if test -d $1
        then
            if [ "$2" = "after" ] ; then
                PATH=$PATH:$1
            else
                PATH=$1:$PATH
            fi
        fi
    fi
}

# OLD VERSION
#pathmunge ()
#{
#    if ! echo $PATH | /bin/egrep "(^|:)$1($|:)" > /dev/null 2>&1
#    then
#        if [ "$2" = "after" ] ; then
#            PATH=$PATH:$1
#        else
#            PATH=$1:$PATH
#        fi
#    fi
#}

# Some path manipulation
pathmunge /usr/local/bin
pathmunge /usr/local/scripts

# Path manipulation for root
if [ `$ID_BIN -u` = 0 ]
then
    pathmunge /usr/sbin
    pathmunge /sbin
    pathmunge /usr/local/sbin
fi

pathmunge ${HOME}/bin
pathmunge ${HOME}/scripts


# Rest of the path manipulation

# In Debian GNU/Linux and other FHS-compliant Linux-distributions
# /usr/X11R6/bin and /usr/bin/X11 are just symlinks pointing to /usr/bin

if test -d /usr/X11R6/bin -a ! -h /usr/X11R6/bin
then
    pathmunge /usr/X11R6/bin after
fi

if test -d /usr/bin/X11 -a ! -h /usr/bin/X11
then
    pathmunge /usr/bin/X11 after
fi


pathmunge /opt/bin after

# Root should not play Quake
#if test ! `$ID_BIN -u` = 0
#then
#    pathmunge /usr/local/games/quake after
#fi

#################################################################
# I have installed almost everything from The Heirloom Project
# http://heirloom.sourceforge.net/

pathmunge ${HOME}/heirloom/5bin/posix2001 after
pathmunge ${HOME}/heirloom/5bin after
pathmunge /opt/heirloom/5bin/posix2001 after
pathmunge /opt/heirloom/5bin after

#################################################################
# I have installed all the stuff from AT&T ast-open
# http://www.research.att.com/~gsf/download/
# http://www.kornshell.com/
#


if test -x ${HOME}/ast/bin/package
then
    ATTASTOPENARCH="`${HOME}/ast/bin/package host`"
    pathmunge ${HOME}/ast/arch/${ATTASTOPENARCH}/bin after
    pathmunge ${HOME}/ast/arch/${ATTASTOPENARCH}/bin/ok after
    unset ATTASTOPENARCH
fi

pathmunge  ${HOME}/ast/bin after

if test -x /opt/ast/bin/package
then
    ATTASTOPENARCH="`/opt/ast/bin/package host`"
    pathmunge /opt/ast/arch/${ATTASTOPENARCH}/bin after
    pathmunge /opt/ast/arch/${ATTASTOPENARCH}/bin/ok after
    unset ATTASTOPENARCH
fi


pathmunge /opt/ast/bin after

#################################################################
# Some other stuff from The Heirloom Project

pathmunge /opt/heirloom/5bin/posix after
pathmunge /opt/heirloom/bin after
pathmunge /opt/heirloom/ucb after
pathmunge /opt/heirloom/5bin/s42 after
pathmunge /opt/heirloom/ccs/bin after



#################################################################
# I installed everything from Plan 9 from User Space
# http://swtch.com/plan9port/
#

if test -x ${HOME}/plan9
then
    PLAN9="${HOME}/plan9"
    export PLAN9   
    #PATH="${PATH}:${PLAN9}/bin"
    pathmunge ${PLAN9}/bin after
fi

if test -x /opt/plan9
then
    PLAN9="/opt/plan9"
    export PLAN9
    #PATH="${PATH}:${PLAN9}/bin"
    pathmunge ${PLAN9}/bin after
fi

#################################################################

#unset pathmunge

export PATH

cd ${HOME}

# }}}

case $TERM in *linux*|*putty*)
    if type ctheme > /dev/null 2>&1
    then
        CTHEME="xterm16.ct"

        OLDPATH="$PATH"
        PATH="/usr/local/share/cthemes:/usr/share/cthemes:$PATH"
        $CTHEME
        PATH="$OLDPATH"
        export PATH
        unset CTHEME
    fi
esac

